summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--content/urldb.c13
1 files changed, 7 insertions, 6 deletions
diff --git a/content/urldb.c b/content/urldb.c
index 905c5befe..40f6f1f65 100644
--- a/content/urldb.c
+++ b/content/urldb.c
@@ -1305,13 +1305,14 @@ bool urldb_iterate_partial_path(const struct path_data *parent,
NULL))
return false;
- break;
- }
-
- /* Skip over this segment */
- prefix = slash + 1;
+ /* Progress to next sibling */
+ p = p->next;
+ } else {
+ /* Skip over this segment */
+ prefix = slash + 1;
- p = p->children;
+ p = p->children;
+ }
} else {
/* Doesn't match this segment, try next sibling */
p = p->next;